@@ -6,31 +6,25 @@
  */
 
 #include "icon.h"
-
-#include <grantlee/exception.h>
-#include <grantlee/parser.h>
-#include <grantlee/variable.h>
+#include <KTextTemplate/Exception>
+#include <KTextTemplate/Parser>
+#include <KTextTemplate/Variable>
 
 #include <KIconLoader>
 
 IconTag::IconTag(QObject *parent)
-    : Grantlee::AbstractNodeFactory(parent)
+    : KTextTemplate::AbstractNodeFactory(parent)
 {
 }
 
-IconTag::~IconTag()
-{
-}
-
-Grantlee::Node *IconTag::getNode(const QString &tagContent, Grantlee::Parser *p) const
+IconTag::~IconTag() = default;
+KTextTemplate::Node *IconTag::getNode(const QString &tagContent, KTextTemplate::Parser *p) const
 {
     Q_UNUSED(p)
 
-    static QHash<QString, int> sizeOrGroupLookup = {{QStringLiteral("desktop"), KIconLoader::Desktop},
-                                                    {QStringLiteral("toolbar"), KIconLoader::Toolbar},
+    static QHash<QString, int> sizeOrGroupLookup = {{QStringLiteral("toolbar"), KIconLoader::Toolbar},
                                                     {QStringLiteral("maintoolbar"), KIconLoader::MainToolbar},
                                                     {QStringLiteral("small"), KIconLoader::Small},
-                                                    {QStringLiteral("panel"), KIconLoader::Panel},
                                                     {QStringLiteral("dialog"), KIconLoader::Dialog},
                                                     {QStringLiteral("sizesmall"), KIconLoader::SizeSmall},
                                                     {QStringLiteral("sizesmallmedium"), KIconLoader::SizeSmallMedium},
@@ -42,10 +36,10 @@ Grantlee::Node *IconTag::getNode(const QString &tagContent, Grantlee::Parser *p)
     const QStringList parts = smartSplit(tagContent);
     const int partsSize = parts.size();
     if (partsSize < 2) {
-        throw Grantlee::Exception(Grantlee::TagSyntaxError, QStringLiteral("icon tag takes at least 1 argument"));
+        throw KTextTemplate::Exception(KTextTemplate::TagSyntaxError, QStringLiteral("icon tag takes at least 1 argument"));
     }
     if (partsSize > 4) {
-        throw Grantlee::Exception(Grantlee::TagSyntaxError, QStringLiteral("icon tag takes at maximum 3 arguments, %1 given").arg(partsSize));
+        throw KTextTemplate::Exception(KTextTemplate::TagSyntaxError, QStringLiteral("icon tag takes at maximum 3 arguments, %1 given").arg(partsSize));
     }
 
     int sizeOrGroup = KIconLoader::Small;
@@ -74,23 +68,20 @@ Grantlee::Node *IconTag::getNode(const QString &tagContent, Grantlee::Parser *p)
 }
 
 IconNode::IconNode(QObject *parent)
-    : Grantlee::Node(parent)
+    : KTextTemplate::Node(parent)
 {
 }
 
 IconNode::IconNode(const QString &iconName, int sizeOrGroup, const QString &altText, QObject *parent)
-    : Grantlee::Node(parent)
+    : KTextTemplate::Node(parent)
     , mIconName(iconName)
     , mAltText(altText)
     , mSizeOrGroup(sizeOrGroup)
 {
 }
 
-IconNode::~IconNode()
-{
-}
-
-void IconNode::render(Grantlee::OutputStream *stream, Grantlee::Context *c) const
+IconNode::~IconNode() = default;
+void IconNode::render(KTextTemplate::OutputStream *stream, KTextTemplate::Context *c) const
 {
     Q_UNUSED(c)
 
@@ -98,11 +89,11 @@ void IconNode::render(Grantlee::OutputStream *stream, Grantlee::Context *c) cons
     if (iconName.startsWith(QLatin1Char('"')) && iconName.endsWith(QLatin1Char('"'))) {
         iconName = iconName.mid(1, iconName.size() - 2);
     } else {
-        const QVariant val = Grantlee::Variable(mIconName).resolve(c);
-        if (val.type() == QVariant::String) {
+        const QVariant val = KTextTemplate::Variable(mIconName).resolve(c);
+        if (val.metaType().id() == QMetaType::QString) {
             iconName = val.toString();
         } else {
-            iconName = val.value<Grantlee::SafeString>().get();
+            iconName = val.value<KTextTemplate::SafeString>().get();
         }
     }
 
@@ -111,10 +102,10 @@ void IconNode::render(Grantlee::OutputStream *stream, Grantlee::Context *c) cons
         if (mAltText.startsWith(QLatin1Char('"')) && mAltText.endsWith(QLatin1Char('"'))) {
             altText = mAltText.mid(1, mAltText.size() - 2);
         } else {
-            const QVariant v = Grantlee::Variable(mAltText).resolve(c);
+            const QVariant v = KTextTemplate::Variable(mAltText).resolve(c);
             if (v.isValid()) {
-                if (v.canConvert<Grantlee::SafeString>()) {
-                    altText = v.value<Grantlee::SafeString>().get();
+                if (v.canConvert<KTextTemplate::SafeString>()) {
+                    altText = v.value<KTextTemplate::SafeString>().get();
                 } else {
                     altText = v.toString();
                 }
@@ -127,5 +118,7 @@ void IconNode::render(Grantlee::OutputStream *stream, Grantlee::Context *c) cons
             .arg(KIconLoader::global()->iconPath(iconName, mSizeOrGroup < KIconLoader::LastGroup ? mSizeOrGroup : -mSizeOrGroup))
             .arg(mSizeOrGroup < KIconLoader::LastGroup ? KIconLoader::global()->currentSize(static_cast<KIconLoader::Group>(mSizeOrGroup)) : mSizeOrGroup)
             .arg(altText.isEmpty() ? iconName : altText, altText); // title is intentionally blank if no alt is provided
-    (*stream) << Grantlee::SafeString(html, Grantlee::SafeString::IsSafe);
+    (*stream) << KTextTemplate::SafeString(html, KTextTemplate::SafeString::IsSafe);
 }
+
+#include "moc_icon.cpp"
